NAME

BSD::Jail - Perl extension for FreeBSD jail()

SYNOPSIS

use BSD::Jail;

# Get a list of current prisons
my @jids = get_jids();

# Get information on a prision
my ($pr_version, $pr_id, $pr_path, $pr_host, $pr_ipaddr) =
    get_xprison($jid);

# Attach to a prison
jattach($jid);

# Create a new prision and get locked into it
jail($path, $hostname, $ipaddr);

DESCRIPTION

The BSD::Jail module is an interface to the jail(2) system call found in
FreeBSD.  It can get information on current prisons, attach to current
prisons and create new prisons.

To create or attach to a prison, the process must be running as root.

AUTHOR

Travis Boucher <tbone@tbone.ca>

SEE ALSO

perl.